@@ -10,9 +10,22 @@ has 'parsed_attributes' => (
     },
     is     => 'ro',
     isa    => 'HashRef',
+    lazy   => 1,
     traits => [qw(Hash)],
 );
 
+has 'default_attributes' => (
+    default => sub { {} },
+    is      => 'rw',
+    isa     => 'HashRef',
+);
+
+has 'override_attributes' => (
+    default => sub { {} },
+    is      => 'rw',
+    isa     => 'HashRef',
+);
+
 sub _parse_attributes {
     my ($self) = @_;
 
@@ -28,13 +41,21 @@ sub _parse_attributes {
         MaxChilds => 1,
     };
 
+    foreach my $attr ( keys %{ $self->default_attributes } ) {
+        unshift @$attributes, sprintf '%s(%s)', $attr, $self->default_attributes->{$attr};
+    }
+
+    foreach my $attr ( keys %{ $self->override_attributes } ) {
+        push @$attributes, sprintf '%s(%s)', $attr, $self->override_attributes->{$attr};
+    }
+
     foreach my $attr (@$attributes) {
         my ( $type, $value ) = $attr =~ / (\w+) (?: \( (.*?) \) )*/x;
 
         # Default values
         $value ||= 'encode' if $type eq 'Encode';
         $value ||= 'decode' if $type eq 'Decode';
-        $value ||= 1;
+        $value = 1 unless defined $value;
 
         unless ( grep $type eq $_, @valid_attributes ) {
             warn "Invalid attribute '$attr' in " . ref($self);
