@@ -32,4 +32,24 @@ $driver->add_job(
     }
 );
 
+$driver->add_job(
+    {
+        max_childs => 10,
+        method     => $w1->meta->find_method_by_name('ten_childs')->body,
+        min_childs => 10,
+        name       => 'Live::NS3::AddJob::ten_childs',
+        object     => $w1,
+    }
+);
+
+$driver->add_job(
+    {
+        max_childs => 6,
+        method     => $w1->meta->find_method_by_name('sleeper')->body,
+        min_childs => 2,
+        name       => 'Live::NS3::AddJob::sleeper',
+        object     => $w1,
+    }
+);
+
 $driver->run;
